@@ -67,19 +67,23 @@ MicroBlog::MicroBlog(QObject *parent, const QVariantList &args)
       m_wallet(0),
       m_walletWait(None),
       m_colorScheme(0),
-      m_showTweetsTimer(0)
+      m_showTweetsTimer(0),
+      m_getWalletDelayTimer(0)
 {
     setAspectRatioMode(Plasma::IgnoreAspectRatio);
     setHasConfigurationInterface(true);
     setPopupIcon("view-pim-journal");
+    setAssociatedApplication("choqok");
 }
 
 void MicroBlog::init()
 {
+    m_engine = dataEngine("microblog");
     m_flash = new Plasma::FlashingLabel(this);
     m_theme = new Plasma::Svg(this);
     m_theme->setImagePath("widgets/microblog");
     m_theme->setContainsMultipleImages(true);
+    configChanged();
 }
 
 void MicroBlog::constraintsEvent(Plasma::Constraints constraints)
@@ -159,17 +163,7 @@ QGraphicsWidget *MicroBlog::graphicsWidget()
     m_colorScheme = new KColorScheme(QPalette::Active, KColorScheme::View, Plasma::Theme::defaultTheme()->colorScheme());
     connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(themeChanged()));
 
-    //config stuff
-    KConfigGroup cg = config();
-    m_serviceUrl = cg.readEntry("serviceUrl", "https://identi.ca/api/");
-    m_username = cg.readEntry("username");
-    m_password = KStringHandler::obscure(cg.readEntry("password"));
-    m_historySize = cg.readEntry("historySize", 6);
-    m_historyRefresh = cg.readEntry("historyRefresh", 5);
-    m_includeFriends = cg.readEntry("includeFriends", true);
-
-    m_engine = dataEngine("microblog");
-    if (! m_engine->isValid()) {
+    if (!m_engine->isValid()) {
         setFailedToLaunch(true, i18n("Failed to load twitter DataEngine"));
         return m_graphicsWidget;
     }
@@ -221,6 +215,7 @@ QGraphicsWidget *MicroBlog::graphicsWidget()
     QGraphicsLinearLayout *statusEditLayout = new QGraphicsLinearLayout(statusEditFrame);
     m_statusEdit = new Plasma::TextEdit(this);
     m_statusEdit->setPreferredHeight(fm.height() * 4);
+    m_statusEdit->setEnabled(!configurationRequired());
 
     connect(m_statusEdit, SIGNAL(textChanged()), this, SLOT(editTextChanged()));
     statusEditLayout->addItem(m_statusEdit);
@@ -253,25 +248,124 @@ QGraphicsWidget *MicroBlog::graphicsWidget()
 
     m_layout->addItem(m_scrollWidget);
 
-    //hook up some sources
-    m_imageQuery = "UserImages:" + m_serviceUrl;
-    m_engine->connectSource(m_imageQuery, this);
+    m_graphicsWidget->setPreferredSize(300, 400);
 
+    if (!m_imageQuery.isEmpty()) {
+        m_engine->connectSource(m_imageQuery, this);
+    }
 
+    return m_graphicsWidget;
+}
+
+void MicroBlog::configChanged()
+{
+    //config stuff
+    KConfigGroup cg = config();
+    QString serviceUrl = cg.readEntry("serviceUrl", "https://identi.ca/api/");
+    QString username = cg.readEntry("username");
+    QString password = KStringHandler::obscure(cg.readEntry("password"));
+    int historySize = cg.readEntry("historySize", 6);
+    int historyRefresh = cg.readEntry("historyRefresh", 5);
+    bool includeFriends = cg.readEntry("includeFriends", true);
+    bool changed = false;
+    bool reloadRequired = false;
+
+    if (m_serviceUrl != serviceUrl) {
+        m_serviceUrl = serviceUrl;
+        changed = true;
+        reloadRequired = true;
+    }
+
+    if (username != m_username) {
+        m_username = username;
+        changed = true;
+        reloadRequired = true;
+        m_tweetMap.clear();
+        m_lastTweet = 0;
+
+        if (m_graphicsWidget) {
+            m_icon->setIcon(KIcon("user-identity"));
+            m_icon->setText(m_username);
+        }
+    }
+
+    //if (m_walletWait == Read)
+    //then the user is a dumbass.
+    //we're going to ignore that, which drops the read attempt
+    //I hope that doesn't cause trouble.
+    if (!m_username.isEmpty() && (changed || m_password.isEmpty())) {
+        //a change in name *or* pass means we need to update the wallet
+        //if the user doesn't set a password, see if it's already in our wallet
+        m_walletWait = m_password.isEmpty() ? Read : Write;
+        getWallet();
+    }
+
+    if (m_historyRefresh != historyRefresh) {
+        changed = true;
+        m_historyRefresh = historyRefresh;
+    }
+
+    if (m_includeFriends != includeFriends) {
+        changed = true;
+        reloadRequired = true;
+        m_includeFriends = includeFriends;
+        m_tweetMap.clear();
+        m_lastTweet = 0;
+    }
+
+    if (m_historySize != historySize) {
+        //kDebug() << "m_historysize,historysize: "<<m_historySize << historySize;
+        if (m_historySize < historySize) {
+            reloadRequired = true;
+        } else if (!reloadRequired) {
+            showTweets();
+        }
+
+        changed = true;
+        m_historySize = historySize;
+    }
+
+    //kDebug() << changed << reloadRequired;
     //set things in motion
+    //hook up some sources
+    if (!m_imageQuery.isEmpty()) {
+        m_engine->disconnectSource(m_imageQuery, this);
+    }
+
+    m_imageQuery = "UserImages:" + m_serviceUrl;
+    if (m_graphicsWidget) {
+        m_engine->connectSource(m_imageQuery, this);
+    }
+
     if (m_username.isEmpty()) {
         setAuthRequired(true);
     } else if (m_password.isEmpty()) {
-        kDebug() << "started, password is not in config file, trying wallet";
+        //kDebug() << "started, password is not in config file, trying wallet";
         m_walletWait = Read;
         getWallet();
     } else { //use config value
-        kDebug() << "password was in config file, using that to get twitter history";
+        //kDebug() << "password was in config file, using that to get twitter history";
         downloadHistory();
     }
 
-    m_graphicsWidget->setPreferredSize(300, 400);
-    return m_graphicsWidget;
+    if (changed) {
+        if (m_service) {
+            m_service->deleteLater();
+            m_service = 0;
+        }
+
+        if (m_profileService) {
+            m_profileService->deleteLater();
+            m_profileService = 0;
+        }
+    }
+
+    if (reloadRequired) {
+        m_lastTweet = 0;
+        downloadHistory();
+    }
+
+    setAuthRequired(m_username.isEmpty());
 }
 
 void MicroBlog::modeChanged(int)
@@ -281,8 +375,9 @@ void MicroBlog::modeChanged(int)
     downloadHistory();
 }
 
-void MicroBlog::reply(const QString &to)
+void MicroBlog::reply(const QString &replyToId, const QString &to)
 {
+    m_replyToId = replyToId;
     m_scrollWidget->ensureItemVisible(m_headerFrame);
     m_statusEdit->nativeWidget()->setPlainText(to);
     QTextCursor cursor = m_statusEdit->nativeWidget()->textCursor();
@@ -302,6 +397,7 @@ void MicroBlog::getWallet()
 {
     //TODO: maybe Plasma in general should handle the wallet
     delete m_wallet;
+    m_wallet = 0;
 
     QGraphicsView *v = view();
     WId w = 0;
@@ -309,7 +405,26 @@ void MicroBlog::getWallet()
         w = v->winId();
     }
 
-    kDebug() << "opening wallet";
+    if (!w) {
+        //KWallet requires a valid window id to work, wait until we have one
+        if (!m_getWalletDelayTimer) {
+            m_getWalletDelayTimer = new QTimer(this);
+            m_getWalletDelayTimer->setSingleShot(true);
+            m_getWalletDelayTimer->setInterval(100);
+            connect(m_getWalletDelayTimer, SIGNAL(timeout()), this, SLOT(getWallet()));
+        }
+
+        if (!m_getWalletDelayTimer->isActive()) {
+            m_getWalletDelayTimer->start();
+        }
+
+        return;
+    } else {
+        delete m_getWalletDelayTimer;
+        m_getWalletDelayTimer = 0;
+    }
+
+    //kDebug() << "opening wallet";
     m_wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(),
                                            w, KWallet::Wallet::Asynchronous);
 
@@ -322,15 +437,15 @@ void MicroBlog::getWallet()
 
 void MicroBlog::writeWallet(bool success)
 {
-    kDebug() << success;
+    //kDebug() << success;
     if (success &&
         enterWalletFolder(QString::fromLatin1("Plasma-MicroBlog")) &&
         (m_wallet->writePassword(m_username, m_password) == 0)) {
-        kDebug() << "successfully put password in wallet, removing from config file";
+        //kDebug() << "successfully put password in wallet, removing from config file";
         config().deleteEntry("password");
         emit configNeedsSaving();
     } else {
-        kDebug() << "failed to store password in wallet, putting into config file instead";
+        //kDebug() << "failed to store password in wallet, putting into config file instead";
         writeConfigPassword();
     }
     m_walletWait = None;
@@ -340,20 +455,26 @@ void MicroBlog::writeWallet(bool success)
 
 void MicroBlog::readWallet(bool success)
 {
-    kDebug() << success;
+    //kDebug() << success;
     QString pwd;
     if (success &&
         enterWalletFolder(QString::fromLatin1("Plasma-MicroBlog")) &&
         (m_wallet->readPassword(m_username, pwd) == 0)) {
-        kDebug() << "successfully retrieved password from wallet";
+        //kDebug() << "successfully retrieved password from wallet";
         m_password = pwd;
         downloadHistory();
     } else if (m_password.isEmpty()) {
         //FIXME: when out of string freeze, tell the user WHY they need
         //       to configure the widget;
-        setConfigurationRequired(true);
-        kDebug() << "failed to read password";
-    }
+		m_password = KStringHandler::obscure(config().readEntry("password"));
+		if(m_password.isEmpty()){
+	        setConfigurationRequired(true, i18n("Your password is required."));
+		}else{
+			//kDebug() << "reading from config";
+        	//kDebug() << "failed to read password";
+			downloadHistory();
+		}
+    }	
 
     m_walletWait = None;
     delete m_wallet;
@@ -366,18 +487,20 @@ bool MicroBlog::enterWalletFolder(const QString &folder)
     //why doesn't kwallet have this itself?
     m_wallet->createFolder(folder);
     if (! m_wallet->setFolder(folder)) {
-        kDebug() << "failed to open folder" << folder;
+        //kDebug() << "failed to open folder" << folder;
         return false;
     }
 
-    kDebug() << "wallet now on folder" << folder;
+    //kDebug() << "wallet now on folder" << folder;
     return true;
 }
 
 void MicroBlog::setAuthRequired(bool required)
 {
-    setConfigurationRequired(required);
-    m_statusEdit->setEnabled(!required);
+    setConfigurationRequired(required, i18n("Your account information is incomplete."));
+    if (m_graphicsWidget) {
+        m_statusEdit->setEnabled(!required);
+    }
 }
 
 void MicroBlog::writeConfigPassword()
@@ -495,6 +618,10 @@ void MicroBlog::scheduleShowTweets()
 
 void MicroBlog::showTweets()
 {
+    if (!m_graphicsWidget) {
+        return;
+    }
+
     prepareGeometryChange();
     // Adjust the number of the TweetWidgets if the configuration has changed
     // Add more tweetWidgets if there are not enough
@@ -508,7 +635,7 @@ void MicroBlog::showTweets()
 
     while (m_tweetWidgets.count() < m_tweetMap.count()) {
         PostWidget *postWidget = new PostWidget(m_tweetsWidget);
-        connect(postWidget, SIGNAL(reply(const QString &)), this, SLOT(reply(const QString &)));
+        connect(postWidget, SIGNAL(reply(const QString &, const QString &)), this, SLOT(reply(const QString &, const QString &)));
         connect(postWidget, SIGNAL(forward(const QString &)), this, SLOT(forward(const QString &)));
         connect(postWidget, SIGNAL(openProfile(const QString &)), this, SLOT(openProfile(const QString &)));
         m_tweetWidgets.append(postWidget);
@@ -547,7 +674,7 @@ void MicroBlog::showTweets()
     }
 
     //are we complete?
-    if (layout()->itemAt(0) != m_graphicsWidget) {
+    if (layout() && layout()->itemAt(0) != m_graphicsWidget) {
         paintIcon();
     }
 }
@@ -576,87 +703,19 @@ void MicroBlog::createConfigurationInterface(KConfigDialog *parent)
 
 void MicroBlog::configAccepted()
 {
-    QString serviceUrl = configUi.serviceUrlCombo->currentText();
-    QString username = configUi.usernameEdit->text();
-    QString password = configUi.passwordEdit->text();
-    int historyRefresh = configUi.historyRefreshSpinBox->value();
-    int historySize = configUi.historySizeSpinBox->value();
-    bool includeFriends = configUi.checkIncludeFriends->isChecked();
-    bool changed = false;
-    bool reloadRequired = false;
-
     KConfigGroup cg = config();
+	//kDebug()<<"Inside configAccepted";
+	//kDebug()<<"username: "<<configUi.usernameEdit->text();
+    cg.writeEntry("serviceUrl", configUi.serviceUrlCombo->currentText());
+    cg.writeEntry("username", configUi.usernameEdit->text());
+    cg.writeEntry("historyRefresh", configUi.historyRefreshSpinBox->value());
+    cg.writeEntry("includeFriends", configUi.checkIncludeFriends->isChecked());
+    cg.writeEntry("historySize", configUi.historySizeSpinBox->value());
 
-    m_engine->disconnectSource(m_imageQuery, this);
-
-    if (m_serviceUrl != serviceUrl) {
-        changed = true;
-        reloadRequired = true;
-        m_serviceUrl = serviceUrl;
-        cg.writeEntry( "serviceUrl", m_serviceUrl );
-    }
-
-
-    if (m_username != username) {
-        changed = true;
-        reloadRequired = true;
-        m_username = username;
-        m_icon->setIcon( QIcon() );
-        m_icon->setText( m_username );
-        cg.writeEntry( "username", m_username );
-        m_tweetMap.clear();
-        m_lastTweet = 0;
-    }
-
-    m_imageQuery = "UserImages:" + m_serviceUrl;
-    m_engine->connectSource(m_imageQuery, this);
-
+    QString password = configUi.passwordEdit->text();
     if (m_password != password) {
-        changed = true;
         m_password = password;
-    }
 
-    //if (m_walletWait == Read)
-    //then the user is a dumbass.
-    //we're going to ignore that, which drops the read attempt
-    //I hope that doesn't cause trouble.
-    if (!m_username.isEmpty() && (changed || m_password.isEmpty())) {
-        //a change in name *or* pass means we need to update the wallet
-        //if the user doesn't set a password, see if it's already in our wallet
-        m_walletWait = m_password.isEmpty() ? Read : Write;
-        getWallet();
-    }
-
-    if (m_historyRefresh != historyRefresh) {
-        changed = true;
-        m_historyRefresh = historyRefresh;
-        cg.writeEntry("historyRefresh", m_historyRefresh);
-    }
-
-    if (m_includeFriends != includeFriends) {
-        changed = true;
-        reloadRequired = true;
-        m_includeFriends = includeFriends;
-        m_tweetMap.clear();
-        m_lastTweet = 0;
-        cg.writeEntry("includeFriends", m_includeFriends);
-    }
-
-    if (m_historySize != historySize) {
-        //kDebug() << m_historySize << historySize;
-        if (m_historySize < historySize) {
-            reloadRequired = true;
-        } else if (!reloadRequired) {
-            showTweets();
-        }
-
-        changed = true;
-        m_historySize = historySize;
-        cg.writeEntry("historySize", m_historySize);
-    }
-
-    //kDebug() << changed << reloadRequired;
-    if (changed) {
         if (m_service) {
             m_service->deleteLater();
             m_service = 0;
@@ -666,16 +725,9 @@ void MicroBlog::configAccepted()
             m_profileService->deleteLater();
             m_profileService = 0;
         }
-
-        if (reloadRequired) {
-            m_lastTweet = 0;
-            downloadHistory();
-        }
-
-        emit configNeedsSaving();
     }
 
-    setAuthRequired(m_username.isEmpty());
+    emit configNeedsSaving();
 }
 
 MicroBlog::~MicroBlog()
@@ -688,6 +740,10 @@ MicroBlog::~MicroBlog()
 void MicroBlog::editTextChanged()
 {
     m_flash->flash(i18np("%1 character left", "%1 characters left", 140 - m_statusEdit->nativeWidget()->toPlainText().length()), 2000);
+    //if the text has been cleared, discard
+    if (m_statusEdit->nativeWidget()->toPlainText().length() == 0) {
+        m_replyToId = QString();
+    }
 }
 
 bool MicroBlog::eventFilter(QObject *obj, QEvent *event)
@@ -730,6 +786,9 @@ void MicroBlog::updateStatus()
     KConfigGroup cg = m_service->operationDescription("update");
     cg.writeEntry("password", m_password);
     cg.writeEntry("status", status);
+    if (!m_replyToId.isEmpty()) {
+        cg.writeEntry("inReplyToStatusId", m_replyToId);
+    }
 
     connect(m_service, SIGNAL(finished(Plasma::ServiceJob*)), this, SLOT(updateCompleted(Plasma::ServiceJob*)), Qt::UniqueConnection);
 
@@ -759,8 +818,9 @@ void MicroBlog::updateCompleted(Plasma::ServiceJob *job)
 //what this really means now is 'reconnect to the timeline source'
 void MicroBlog::downloadHistory()
 {
-    //kDebug() ;
+   // kDebug() << "Inside downloadhistory";
     if (m_username.isEmpty() || m_password.isEmpty()) {
+		//kDebug() << "BOOHYA got empty password";
         if (!m_curTimeline.isEmpty()) {
             m_engine->disconnectSource(m_curTimeline, this);
             m_engine->disconnectSource("Error:" + m_curTimeline, this);
