@@ -25,15 +25,18 @@
 #include <plasma/theme.h>
 
 FuncKey::FuncKey(QPoint relativePosition, QSize relativeSize, unsigned int keycode, QString label):
-        AlphaNumKey(relativePosition, relativeSize, keycode) {
+        AlphaNumKey(relativePosition, relativeSize, keycode)
+{
     setLabel(label);
 }
 
-void FuncKey::paint(QPainter *painter){
+void FuncKey::paint(QPainter *painter)
+{
     AlphaNumKey::paint(painter);
 }
 
-void FuncKey::paintArrow(QPainter *painter){
+void FuncKey::paintArrow(QPainter *painter)
+{
 
     int unit = qMin(size().width(), size().height()) / 8;
     painter->drawLine(-1*unit, 0 , 3*unit, 0);
@@ -52,6 +55,7 @@ void FuncKey::paintLabel(QPainter *painter)
     painter->save();
     int fontSize = qMin(size().width(), size().height()) / 5 - (label().size()/6 + 1);
     painter->setFont(QFont( Plasma::Theme::defaultTheme()->font(Plasma::Theme::DefaultFont).toString(), fontSize ));
+    painter->setPen(Plasma::Theme::defaultTheme()->color(Plasma::Theme::ButtonTextColor));
     painter->drawText(rect(), Qt::AlignCenter, label());
     
     painter->restore();
