@@ -21,7 +21,9 @@
 #include "timelinesource.h"
 
 #include <QXmlStreamReader>
+#include <QtCrypto>
 
+#include <KDebug>
 #include <KIO/Job>
 
 #include "imagesource.h"
@@ -37,9 +39,12 @@ TweetJob::TweetJob(TimelineSource *source, const QMap<QString, QVariant> &parame
       m_source(source)
 {
     m_status = parameters.value("status").toString();
+    m_inReplyToStatusId = parameters.value("inReplyToStatusId").toString();
+
     if (!source->useOAuth()) {
         m_url.addQueryItem("status", m_status);
         m_url.addQueryItem("source", "kdemicroblog");
+        m_url.addQueryItem("in_reply_to_status_id", m_inReplyToStatusId);
 
         m_url.setUser(source->account());
         m_url.setPass(source->password());
@@ -49,12 +54,17 @@ TweetJob::TweetJob(TimelineSource *source, const QMap<QString, QVariant> &parame
 void TweetJob::start()
 {
     QByteArray data = (m_source->useOAuth()) ? "status=" + m_status.toUtf8().toPercentEncoding()
-                                    + "&source=kdemicroblog" : QByteArray();
+                         + "&source=kdemicroblog"
+                         + (!m_inReplyToStatusId.isEmpty()?"&in_reply_to_status_id=" + m_inReplyToStatusId.toLatin1() : "")
+                       : QByteArray();
     KIO::Job *job = KIO::http_post(m_url, data, KIO::HideProgressInfo);
     if (m_source->useOAuth()){
         OAuth::ParamMap params;
         params.insert("status", m_status.toUtf8().toPercentEncoding());
         params.insert("source", "kdemicroblog");
+        if (!m_inReplyToStatusId.isEmpty()) {
+            params.insert("in_reply_to_status_id", m_inReplyToStatusId.toLatin1());
+        }
         OAuth::signRequest(job, m_url.pathOrUrl(), OAuth::POST, m_source->oauthToken(),
                            m_source->oauthTokenSecret(), params);
     }
@@ -91,7 +101,8 @@ Plasma::ServiceJob* TimelineService::createJob(const QString &operation, QMap<QS
 TimelineSource::TimelineSource(const QString &who, RequestType requestType, QObject* parent)
     : Plasma::DataContainer(parent),
       m_job(0),
-      m_authJob(0)
+      m_authJob(0),
+      m_qcaInitializer(0)
 {
     //who should be something like user@http://twitter.com, if there isn't any @, http://twitter.com will be the default
     QStringList account = who.split('@');
@@ -104,6 +115,9 @@ TimelineSource::TimelineSource(const QString &who, RequestType requestType, QObj
 
     m_useOAuth = (m_serviceBaseUrl == KUrl("https://twitter.com/")) ? true : false;
 
+        //just create it to correctly initialize QCA and clean up when createSignature() returns
+    m_qcaInitializer = new QCA::Initializer();
+
     // set up the url
     switch (requestType) {
     case Profile:
@@ -134,6 +148,7 @@ TimelineSource::TimelineSource(const QString &who, RequestType requestType, QObj
 
 TimelineSource::~TimelineSource()
 {
+    delete m_qcaInitializer;
 }
 
 Plasma::Service* TimelineSource::createService()
@@ -237,6 +252,7 @@ void TimelineSource::result(KJob *job)
     }
 
     removeAllData();
+    m_imageSource->loadStarted();
     if (job->error()) {
         //kDebug() << "job error!";
         // TODO: error handling
@@ -246,6 +262,7 @@ void TimelineSource::result(KJob *job)
         parse(reader);
         //kDebug() << "parsing through .." << data().count();
     }
+    m_imageSource->loadFinished();
 
     checkForUpdate();
     m_xml.clear();
@@ -264,7 +281,7 @@ void TimelineSource::authFinished(KJob *job)
     }
 
     if (job->error()) {
-        kDebug() << "Authentication Error " << job->error() << ": " << job->errorText() << endl;
+        kDebug() << "Authentication Error " << job->error() << ": " << job->errorText();
     } else {
         QList<QByteArray> pairs = m_oauthTemp.split('&');
 
@@ -337,6 +354,7 @@ void TimelineSource::readStatus(QXmlStreamReader &xml)
             if (tag == "created_at") {
                 m_tempData["Date"] = cdata;
             } else if (tag == "id") {
+                m_tempData["Id"] = cdata;
                 m_id = cdata;
             } else if (tag == "text") {
                 m_tempData["Status"] = cdata;
